/*
 *  Licensed Materials - Property of IBM
 *  5725-G92 (C) Copyright IBM Corp. 2006, 2013. All Rights Reserved.
 *  US Government Users Restricted Rights - Use, duplication or
 *  disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
 */
 
var feeds = null, busy = null;

function loadFeeds() {
	var invocationData = {
		adapter : 'WorklightStarterAdapter',
		procedure : 'getEngadgetFeeds',
		parameters : []
	};
	
	WL.Client.invokeProcedure(invocationData, {
		onSuccess : loadFeedsOK, 
		onFailure : loadFeedsFAIL
	});
}

function loadFeedsOK(data) {
	if (!data || !data.invocationResult || !data.invocationResult.items || data.invocationResult.items.length === 0) {
		Ext.Msg.alert(Messages.noFeedsError);
	}
	
	feeds = data.invocationResult.items;
	loadPage();
}

function loadFeedsFAIL(data) {
	Ext.Msg.alert(Messages.failToPerformAction);
}

function loadPage () {
	Ext.regApplication({
		name : 'workLight',
		launch : function() {
			var tabpanel = new Ext.TabPanel({
				fullscreen : true,
				tabBar : {
					dock : 'bottom',
					layout : {
						pack : 'center'
					}
				},
				cardSwitchAnimation : {
					type : 'slide',
					cover : true
				},
				defaults : {
					scroll : 'vertical'
				},
				items : [
					{
						iconCls : 'favorites',
						title : Messages.backLink,
						xtype : 'panel',
						items : [{
							xtype : 'list',
							store : store,
							itemTpl : '<div class="title">{title}</div><div class="pubDate">{pubDate}</div>',
							onItemDisclosure : function(record, btn, index) {
								showFeed(record, btn, index);
							},
							plugins : [{
								ptype : 'pullrefresh',
								autoPaging : false
							}]
						}],
						dockedItems : [{
							xtype : 'toolbar',
							dock : 'top',
							title : Messages.backLink,
						}]
					}, {
						iconCls : 'info',
						title : Messages.tabAbout,
						html : '<div id="aboutTab"><h2 id="aboutWorklightTitle">' + Messages.aboutWorklightTitle + '</h2><p id="aboutWorklightProductName">' + Messages.aboutWorklightProductName + '</p><p id="aboutWorklightVersion">' + Messages.aboutWorklightVersion + '</p><p id="aboutWorklightText">' + Messages.aboutWorklightText + '</p><a id="aboutWorklightLink" href="https://www.ibm.com/developerworks/mobile/">' + Messages.aboutWorklightLink + '</a></div>',
						dockedItems : [{
							xtype : 'toolbar',
							dock : 'top',
							title : Messages.tabAbout
						}]
					}
				]
			});
		}
	});
	
	Ext.regModel('feeds', {
		fields : ['pubDate', 'title', 'description', 'link']
	});

	var store = new Ext.data.Store({
		model  : 'feeds',
		data : feeds,
	    proxy: {
	        type: 'localstorage',
	        id  : 'twitter-Searches'
	    }
	});
	
	var feedToolbar = new Ext.Toolbar({
		dock : 'top',
		items : [
			{
				text : Messages.backLink,
				ui : 'back',
				handler : function () {
					feed.hide();
					//loadPage();
				}
			}
		]
		          
	});
	
	var feed = new Ext.Panel({
		centered : true,
		dockedItems : feedToolbar,
		floating : true,
		fullscreen : true,
		modal : true,
		scroll : 'vertical',
		styleHtmlContent : true,
	});
	
	var showFeed = function (record, btn, index) {
		feedToolbar.setTitle(Ext.util.Format.ellipsis(record.get('title'), 20));
		feed.update(record.get('description'));
		feed.show();
	};
	
	store.sync();
	busy.hide();
}

function wlCommonInit() {
	busy = new WL.BusyIndicator();
	busy.show();
	loadFeeds();
}